@echo off
@rem ==========================================================================
@rem == Licensed Materials - Property of IBM Corporation
@rem == (C) Copyright IBM Corporation 2019
@rem ==========================================================================
@rem Compiles maps and exports pack resources to be deployed to
@rem a runtime SPE server.
@rem Run this from an SPE console window. This is a WINDOWS ONLY script.
@rem ==========================================================================
@rem
if not defined InSPEConsole echo This command must be run in an SPE console session
if not defined InSPEConsole goto :EOF
Setlocal EnableDelayedExpansion

if     defined DTXHOME goto SKIP_WTX_ENV
if not exist "%SPE_INSTALL_DIR%\bin\spewtxenv.bat" echo Cannot establish WTX environment to compile WTX maps
if not exist "%SPE_INSTALL_DIR%\bin\spewtxenv.bat" goto :EOF
call spewtxenv
:SKIP_WTX_ENV 

set BITS=
set PLATFORM=
set RESOURCE=pack
set JVAL_VRM=2020
set SPE_V_R=spe-9.0
set PACK_V_R_M=10.0.5
set PACK_V_R_M_F=10.0.5.0
set WTX_V_R_M=9.0.0
set PACK=fsp

:READ_COMMAND_LINE_PARMS
if "%1"=="" goto GET_PLATFORM

rem read in -platform
if /i "%1"=="-platform" (
rem read in the -platform value
    set PLATFORM=%2
    shift
    goto READ_NEXT
)

rem read in -bits
if /i "%1"=="-bits" (
rem read in the -bits value: 32 or 64
    set BITS=%2
    shift
    goto READ_NEXT
)

rem read in -resource
if /i "%1"=="-resource" (
rem read in the -resource value: pack or maps
    set RESOURCE=%2
    shift
    goto READ_NEXT
)

rem help syntax
if /i "%1"=="/?" goto SYNTAX

:READ_NEXT
shift
goto READ_COMMAND_LINE_PARMS


:GET_PLATFORM
if defined PLATFORM goto VALIDATE_PLATFORM
echo.
echo Enter target: ALL, AIX, LINUX, WINDOWS
set /p PLATFORM=platform: 
if not defined PLATFORM goto GET_PLATFORM
rem We are in interactive mode, reset RESOURCE to show the prompt
set RESOURCE=

:VALIDATE_PLATFORM
rem convert PLATFORM to uppercase
for %%L IN (A B C D E F G H I J K L M N O P Q R S T U V W X Y Z) DO SET PLATFORM=!PLATFORM:%%L=%%L!
set PLATFORM_ORIGINAL=%PLATFORM%
if /i "%PLATFORM%"=="ALL" (
    set PLATFORM=AIX;LINUX;WINDOWS
    set SUPPORT=aix linux win
    set UNAME=AIX Linux Windows
    goto SET_DEFAULT_BITS
)
if /i "%PLATFORM%"=="AIX" (
    set SUPPORT=aix
    set UNAME=AIX
    goto SET_DEFAULT_BITS
)
if /i "%PLATFORM%"=="LINUX" (
    set SUPPORT=linux
    set UNAME=Linux
    goto SET_DEFAULT_BITS
)
if /i "%PLATFORM%"=="WINDOWS" (
    set SUPPORT=win
    set UNAME=Windows
    goto SET_DEFAULT_BITS
)

echo Invalid platform = "%PLATFORM%"
set PLATFORM=
goto GET_PLATFORM

:SET_DEFAULT_BITS
if defined BITS (
    if not "%BITS%"=="64" (
        echo.
        echo WARNING: setting BITS to the supported 64 instead of %BITS%
    )
)
set BITS=64
goto GET_RESOURCE

:GET_RESOURCE
rem The Pack Installer is delivering most of the files included in the full bundle (pack type)
if defined RESOURCE goto VALIDATE_RESOURCE
echo.
echo Enter the resource type to export: pack (default, press the enter key) or maps
set /p RESOURCE=resource: 
if not defined RESOURCE set RESOURCE=pack

:VALIDATE_RESOURCE
if "%RESOURCE%"=="pack" goto PLATFORM_BITS_OK
if "%RESOURCE%"=="maps" goto PLATFORM_BITS_OK
echo Invalid resource type = "%RESOURCE%"
set RESOURCE=
goto GET_RESOURCE

goto PLATFORM_BITS_OK

:PLATFORM_BITS_OK
cd %SPE_INSTALL_DIR%
if /i "%PLATFORM_ORIGINAL%"=="ALL" (
    set WORKDIR=spe_%PACK%_%RESOURCE%_for_%PLATFORM_ORIGINAL%
) else (
    set WORKDIR=spe_%PACK%_%RESOURCE%_for_%PLATFORM_ORIGINAL%_WTX_%BITS%bit
)
if exist %WORKDIR% rd /s /q %WORKDIR%
if exist %WORKDIR%.jar del %WORKDIR%.jar

rem START PACK SPECIFIC CODE
set TUSCDIR=%WORKDIR%\tpuiserver\usr\shared\config
set TUSRDIR=%WORKDIR%\tpuiserver\usr\shared\resources
set PFCDIR=%WORKDIR%\packs\fsp\codelists
set PFDDIR=%WORKDIR%\packs\fsp\data
set PFMDIR=%WORKDIR%\packs\fsp\maps
set PFMDDIR=%WORKDIR%\packs\fsp\metadata
set PFSMDIR=%WORKDIR%\packs\fsp\sb2bi\maps
set PFSDIR=%WORKDIR%\packs\fsp\schemas
set RMASDIR=%WORKDIR%\resources\maps\autoenvelope\swift
set EFEDIR=%WORKDIR%\examples\fsp\sepa
set EFEMDIR=%WORKDIR%\examples\fsp\sepa\maps
set EFWDIR=%WORKDIR%\examples\fsp\swift
set EFWMDIR=%WORKDIR%\examples\fsp\swift\maps
rem create directories that are not created by xcopy
if not exist "%SPE_INSTALL_DIR%"\%EFEMDIR% mkdir "%SPE_INSTALL_DIR%"\%EFEMDIR%
if not exist "%SPE_INSTALL_DIR%"\%EFWMDIR% mkdir "%SPE_INSTALL_DIR%"\%EFWMDIR%
if "%RESOURCE%"=="maps" goto RESOURCE_MAPS

echo.
echo Copying schemas...
xcopy schema\SPE_IE_Standard_Types_SWIFT.xsd %WORKDIR%\schema\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\wtx\swift\common\schemas\bic.xsd %PFSDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\wtx\swift\common\schemas\ccy.xsd %PFSDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\wtx\swift\mx\schemas\*.xsd %PFSDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\wtx\sepa\mapsandschemas\*.xsd %PFMDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
echo Copying xslt...
xcopy xslt\ie_si_to_spe_swift.xsl %WORKDIR%\xslt\ /i
if ERRORLEVEL 1 goto ERROR
echo.
echo Copying UI files...
xcopy Financial_Services_v%PACK_V_R_M%\tpui\ui_swift_message_types.properties %TUSCDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\tpui\ui_swift_message_types_customer.properties %TUSCDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\tpui\SWIFTenvelope.xml %TUSRDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
echo Copying software tag file
xcopy properties\version\ibm.com_IBM_Transformation_Extender_Pack_for_Financial_Payments_server-%PACK_V_R_M%.swidtag %WORKDIR%\properties\version\ /i
if ERRORLEVEL 1 goto ERROR
echo.
echo Copying codelists...
xcopy Financial_Services_v%PACK_V_R_M%\codelists\*.xml %PFCDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
echo Copying SI break/build maps...
xcopy Financial_Services_v%PACK_V_R_M%\sb2bi\maps\* %PFSMDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
rem example files
echo copying edi example resources...
xcopy Financial_Services_v%PACK_V_R_M%\examples\swift\batchfile.txt %EFWDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\examples\swift\deenvelope\data\* %EFWDIR%\deenvelope\data\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\examples\swift\deenvelope\import\* %EFWDIR%\deenvelope\import\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\examples\swift\deenvelope\wtx_spe_adapter\* %EFWDIR%\deenvelope\wtx_spe_adapter\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\examples\swift\deenvelope\readme.txt %EFWDIR%\deenvelope\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\examples\swift\envelope\data\* %EFWDIR%\envelope\data\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\examples\swift\envelope\import\* %EFWDIR%\envelope\import\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\examples\swift\envelope\wtx_spe_adapter\* %EFWDIR%\envelope\wtx_spe_adapter\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\examples\swift\envelope\readme.txt %EFWDIR%\envelope\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\examples\swift\import\* %EFWDIR%\import\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\examples\sepa\batchfile.txt %EFEDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\examples\sepa\deenvelope\data\* %EFEDIR%\deenvelope\data\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\examples\sepa\deenvelope\import\* %EFEDIR%\deenvelope\import\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\examples\sepa\deenvelope\wtx_spe_adapter\* %EFEDIR%\deenvelope\wtx_spe_adapter\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\examples\sepa\deenvelope\readme.txt %EFEDIR%\deenvelope\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\examples\sepa\envelope\data\* %EFEDIR%\envelope\data\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\examples\sepa\envelope\import\* %EFEDIR%\envelope\import\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\examples\sepa\envelope\wtx_spe_adapter\* %EFEDIR%\envelope\wtx_spe_adapter\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\examples\sepa\envelope\readme.txt %EFEDIR%\envelope\ /i
if ERRORLEVEL 1 goto ERROR
echo.
:RESOURCE_MAPS
echo.
echo Copying jval%JVAL_VRM%.jar...
xcopy Financial_Services_v%PACK_V_R_M%\wtx\swift\mt\jvc\jval%JVAL_VRM%.jar %WORKDIR%\jars\ /i
if ERRORLEVEL 1 goto ERROR
echo.
echo Compiling SWIFT compliance check maps for %PLATFORM%
if not exist %PFMDIR% md %PFMDIR%
set MAP_DIR=%SPE_INSTALL_DIR%\Financial_Services_v%PACK_V_R_M%\wtx\swift\mx\maps
pushd "%MAP_DIR%"
rem check for 9.0.0.* 
set MESSAGE=Could not find a supported version of WTX %WTX_V_R_M%
"%DTXHOME%"\dtxver "%DTXHOME%"\dtxver.exe | findstr "%WTX_V_R_M%\..*)" > nul
if ERRORLEVEL 1 goto ERROR
set MESSAGE=
mcompile mx_acmt_validation.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%PFMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
mcompile mx_camt_validation.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%PFMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
mcompile mx_colr_validation.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%PFMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
mcompile mx_trck_validation.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%PFMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
mcompile mx_head_validation.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%PFMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
mcompile mx_pacs_validation.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%PFMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
mcompile mx_pain_validation.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%PFMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
mcompile mx_reda_validation.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%PFMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
mcompile mx_secl_validation.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%PFMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
mcompile mx_seev_validation.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%PFMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
mcompile mx_semt_validation.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%PFMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
mcompile mx_sese_validation.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%PFMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
mcompile mx_setr_validation.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%PFMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
mcompile mx_tsmt_validation.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%PFMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
mcompile mx_validation_framework.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%PFMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
popd
set MAP_DIR=%SPE_INSTALL_DIR%\Financial_Services_v%PACK_V_R_M%\wtx\sepa\mapsandschemas
pushd "%MAP_DIR%"
mcompile sepa_validation.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%PFMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
mcompile sepa_error_parser.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%PFMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
mcompile sepa_library.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%PFMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
popd
rem autoenvelope schemas and maps must be deploy together to make sure they are in sync.
echo Copying autoenvelope schemas...
xcopy Financial_Services_v%PACK_V_R_M%\wtx\swift\autoenvelope\*.xsd %RMASDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
echo Compiling autoenvelope maps...
set MAP_DIR=%SPE_INSTALL_DIR%\Financial_Services_v%PACK_V_R_M%\wtx\swift\autoenvelope
pushd "%MAP_DIR%"
mcompile swift_autoenvelope.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%RMASDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
popd
echo Copying mt jvc metadata files...
xcopy Financial_Services_v%PACK_V_R_M%\wtx\swift\mt\jvc\metadata\*.xml %PFMDDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo. 
echo Copying xliff.dtd file...
xcopy "%DTXHOME%"\xliff.dtd %PFMDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo. 
echo Copying data and other config files...
xcopy Financial_Services_v%PACK_V_R_M%\wtx\swift\mx\maps\mx_validation_errcodes.txt %PFMDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\wtx\swift\common\data\bic.xml %PFDDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\wtx\swift\common\data\currencycodedecimals.xml %PFDDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\wtx\swift\mt\jvc\maps\jval%JVAL_VRM%.prop %PFMDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\wtx\sepa\mapsandschemas\eeaSEPACtryCd.txt %PFMDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\wtx\sepa\mapsandschemas\epcl.txt %PFMDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\wtx\sepa\mapsandschemas\errc.txt %PFMDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\wtx\sepa\mapsandschemas\sepamsgs.xml %PFMDIR%\ /i
if ERRORLEVEL 1 goto ERROR
rem copy the same files to WORKDIR to be deployed to SPE_INSTALL_DIR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\wtx\swift\mx\maps\mx_validation_errcodes.txt %WORKDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\wtx\swift\common\data\bic.xml %WORKDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\wtx\swift\common\data\currencycodedecimals.xml %WORKDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\wtx\swift\mt\jvc\maps\jval%JVAL_VRM%.prop %WORKDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\wtx\sepa\mapsandschemas\eeaSEPACtryCd.txt %WORKDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\wtx\sepa\mapsandschemas\epcl.txt %WORKDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\wtx\sepa\mapsandschemas\errc.txt %WORKDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Financial_Services_v%PACK_V_R_M%\wtx\sepa\mapsandschemas\sepamsgs.xml %WORKDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
rem example maps
echo Compiling FSP example maps for %PLATFORM%
set MAP_DIR=%SPE_INSTALL_DIR%\Financial_Services_v%PACK_V_R_M%\examples\swift\maps
pushd "%MAP_DIR%"
mcompile credit_transfer_to_mt103+.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%EFWMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
mcompile credit_transfer_to_mx_pacs8.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%EFWMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
mcompile mt103+_to_credit_transfer.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%EFWMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
mcompile mx_pacs8_to_credit_transfer.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%EFWMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
mcompile mx_pain_001_mt101.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%EFWMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
popd
xcopy Financial_Services_v%PACK_V_R_M%\examples\swift\schemas\* %EFWDIR%\schemas\ /i
if ERRORLEVEL 1 goto ERROR
echo.
set MAP_DIR=%SPE_INSTALL_DIR%\Financial_Services_v%PACK_V_R_M%\examples\sepa\maps
pushd "%MAP_DIR%"
mcompile sepa_uk.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%EFEMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
mcompile uk_sepa.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%EFEMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
popd
xcopy Financial_Services_v%PACK_V_R_M%\examples\sepa\schemas\* %EFEDIR%\schemas\ /i
if ERRORLEVEL 1 goto ERROR
echo.
echo Copying example scripts...
if /i "%PLATFORM_ORIGINAL%"=="ALL" (
    xcopy Financial_Services_v%PACK_V_R_M%\examples\bin\spe*samples-packfsp.bat %WORKDIR%\bin\ /i
    if ERRORLEVEL 1 goto ERROR
    xcopy Financial_Services_v%PACK_V_R_M%\examples\bin\spe*samples-packfsp.sh %WORKDIR%\bin\ /i
    if ERRORLEVEL 1 goto ERROR
) else (
    if /i "%PLATFORM_ORIGINAL%"=="WINDOWS" (
        xcopy Financial_Services_v%PACK_V_R_M%\examples\bin\spe*samples-packfsp.bat %WORKDIR%\bin\ /i
        if ERRORLEVEL 1 goto ERROR
    ) else (
        xcopy Financial_Services_v%PACK_V_R_M%\examples\bin\spe*samples-packfsp.sh %WORKDIR%\bin\ /i
        if ERRORLEVEL 1 goto ERROR
    )
)
echo.
rem END PACK SPECIFIC CODE

echo.
cd "%SPE_INSTALL_DIR%\jars"
echo Get the version of the local SPE core jar
if exist %SPE_V_R%-core.jar (
    java com.ibm.spe.core.utils.ReadJarManifest -name=%SPE_V_R%-core.jar -entry=com/ibm/spe/core/ -attribute=Implementation-Version > ..\%WORKDIR%\VERSION
    if ERRORLEVEL 1 goto ERROR    
)
echo.
echo Creating jar file...
cd "%SPE_INSTALL_DIR%\%WORKDIR%"
echo %UNAME%>UNAME
echo %BITS%>BITS
echo %PACK%>PACK
echo %PACK_V_R_M_F%>PACK_VERSION
echo %RESOURCE%>RESOURCE
java com.ibm.spe.core.utils.CreateJarFile -name="%SPE_INSTALL_DIR%\%WORKDIR%.jar" -input="."
if ERRORLEVEL 1 goto ERROR
cd %SPE_INSTALL_DIR%
if not exist %WORKDIR%.jar (
    echo.
    echo Failed to create %SPE_INSTALL_DIR%\%WORKDIR%.jar file!
    goto ERROR
)
echo.
echo Please transfer the %SPE_INSTALL_DIR%\%WORKDIR%.jar to the target SPE server and execute the spedeploy-packs script.
echo.
if exist %WORKDIR% rd /s /q %WORKDIR%
goto :EOF

:ERROR
echo.
echo.%MESSAGE%
echo.
echo There was an ERROR while processing command.
cd %SPE_INSTALL_DIR%
if exist %WORKDIR% rd /s /q %WORKDIR%
echo.
goto :EOF

:SYNTAX
echo Creates a resource jar bundle for %PACK% pack to be deployed to the target server.
echo.
echo speresource-pack%PACK%.bat -platform=target -bits=WTX bits [ -resource=pack, maps ]
echo.
echo Possible values for:  
echo -platform   ALL, AIX, LINUX, WINDOWS
echo -bits            64,   64,     64
echo -resource   pack (default) or maps
echo.
echo WARNING: for 64bit only WTX, the bits value will be ignored if specified.
echo.
goto :EOF
    
:EOF
